package core.api.models.timemanager.taskgroup;

import core.api.models.timemanager.tasks.TaskOverviewInfo;
import core.entities.timemanager.Task;
import core.entities.timemanager.Taskgroup;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

public class RecursiveTaskgroupInfo {

    private long taskgroupID;
    private String taskgroupName;

    private boolean hasOverdueTask;

    private int amountActiveTasks;

    private List<RecursiveTaskgroupInfo> childTaskgroups = new ArrayList<>();

    private List<TaskOverviewInfo> activeTasks = new LinkedList<>();

    public RecursiveTaskgroupInfo(Taskgroup taskgroup) {
        this.taskgroupID = taskgroup.getTaskgroupID();
        this.taskgroupName = taskgroup.getTaskgroupName();

        for(Taskgroup child : taskgroup.getChildren()) {
            this.childTaskgroups.add(new RecursiveTaskgroupInfo(child));
        }

        for(Task task : taskgroup.getActiveTasks()) {
            if(task.getParent() == null) {
                this.activeTasks.add(new TaskOverviewInfo(task));
                if(task.getDeadline() != null && task.getDeadline().isBefore(LocalDate.now())) {
                    this.hasOverdueTask = true;
                }
            }

        }
        this.amountActiveTasks = taskgroup.getAmountOfActiveTasks();
    }

    public long getTaskgroupID() {
        return taskgroupID;
    }

    public void setTaskgroupID(long taskgroupID) {
        this.taskgroupID = taskgroupID;
    }

    public String getTaskgroupName() {
        return taskgroupName;
    }

    public void setTaskgroupName(String taskgroupName) {
        this.taskgroupName = taskgroupName;
    }

    public List<RecursiveTaskgroupInfo> getChildTaskgroups() {
        return childTaskgroups;
    }

    public void setChildTaskgroups(List<RecursiveTaskgroupInfo> childTaskgroups) {
        this.childTaskgroups = childTaskgroups;
    }

    public List<TaskOverviewInfo> getActiveTasks() {
        return activeTasks;
    }

    public void setActiveTasks(List<TaskOverviewInfo> activeTasks) {
        this.activeTasks = activeTasks;
    }

    public boolean isHasOverdueTask() {
        return hasOverdueTask;
    }

    public void setHasOverdueTask(boolean hasOverdueTask) {
        this.hasOverdueTask = hasOverdueTask;
    }

    public int getAmountActiveTasks() {
        return amountActiveTasks;
    }

    public void setAmountActiveTasks(int amountActiveTasks) {
        this.amountActiveTasks = amountActiveTasks;
    }
}
